@@ -1207,6 +1207,189 @@ where
             }
         }
     }
+
+    /// Returns the remaining spare capacity of the array-vector as a slice of `MaybeUninit<T>`.
+    ///
+    /// The returned slice can be used to fill the array-vector with data (e.g. by reading from a
+    /// file) before marking the data as initialized using the [`set_len`] method.
+    ///
+    /// # Examples
+    /// ```rust
+    /// # use cds::array_vec;
+    /// let mut a = array_vec![32; 1, 2];   // <-- an array-vector for IO of 32 elements
+    /// assert_eq!(a, [1, 2]);
+    ///
+    /// let spare_capacity = a.spare_capacity_mut();
+    /// spare_capacity[0].write(3);         // <-- read another 2 elements into the array-vector
+    /// spare_capacity[1].write(4);
+    ///
+    /// unsafe { a.set_len(a.len() + 2) };  // <-- reflect the new size
+    ///
+    /// assert_eq!(a, [1, 2, 3, 4]);
+    /// ```
+    ///
+    /// [`set_len`]: ArrayVec::set_len
+    pub fn spare_capacity_mut(&mut self) -> &mut [mem::MaybeUninit<T>] {
+        unsafe {
+            slice::from_raw_parts_mut(self.arr.as_mut_ptr().add(self.len()), self.spare_capacity())
+        }
+    }
+
+    /// Returns array-vector content as a slice of `T`, along with the remaining spare capacity of
+    /// the array-vector as a slice of `MaybeUninit<T>`.
+    ///
+    /// The returned spare capacity slice can be used to fill the array-vector with data
+    /// (e.g. by reading from a file) before marking the data as initialized using the [`set_len`]
+    /// method.
+    ///
+    /// # Examples
+    /// ```rust
+    /// # use cds::array_vec;
+    /// let mut a = array_vec![32; 1, 2];   // <-- an array-vector for IO of 32 elements
+    ///
+    /// let (init, spare) = a.split_at_spare_mut();
+    /// assert_eq!(init, &[1, 2]);
+    ///
+    /// assert_eq!(spare.len(), 30);        // <-- read another 2 elements into the array-vector
+    /// spare[0].write(3);
+    /// spare[1].write(4);
+    ///
+    /// unsafe { a.set_len(a.len() + 2) };  // <-- reflect the new size
+    ///
+    /// assert_eq!(a, [1, 2, 3, 4]);
+    /// ```
+    ///
+    /// [`set_len`]: ArrayVec::set_len
+    pub fn split_at_spare_mut(&mut self) -> (&mut [T], &mut [mem::MaybeUninit<T>]) {
+        let len = self.len();
+        let spare_capacity = self.spare_capacity();
+        let p = self.as_mut_ptr();
+
+        unsafe {
+            (
+                slice::from_raw_parts_mut(p, len),
+                slice::from_raw_parts_mut(p.add(len) as *mut mem::MaybeUninit<T>, spare_capacity),
+            )
+        }
+    }
+
+    /// Resizes the array-vector in-place so that `len` is equal to `new_len`.
+    ///
+    /// If `new_len` is greater than `len`, the array-vector is extended by the difference,
+    /// with each additional slot filled with the result of calling the closure `f`.
+    /// The return values from `f` will end up in the array-vector in the order they have been
+    /// generated.
+    ///
+    /// If `new_len` is less than `len`, the array-vector is simply truncated.
+    ///
+    /// This method uses a closure to create new values on every push.
+    /// If you’d rather [`Clone`] a given value, use [`try_resize`].
+    /// If you want to use the [`Default`] trait to generate values, you can pass
+    /// [`Default::default`] as the second argument.
+    ///
+    /// # Panics
+    ///
+    /// This method panics of `new_len > CAPACITY`. To avoid panic use [`try_resize_with`] which
+    /// returns [`CapacityError`] instead.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use cds::array_vec;
+    /// let mut a = array_vec![5; 1];
+    /// assert_eq!(a, [1]);
+    ///
+    /// let mut g = 1;
+    ///
+    /// a.resize_with(3, || { g += 1; g });
+    /// assert_eq!(a, [1, 2, 3]);
+    ///
+    /// a.resize_with(5, || { g *= 2; g });
+    /// assert_eq!(a, [1, 2, 3, 6, 12]);
+    ///
+    /// a.resize_with(1, || 0);
+    /// assert_eq!(a, [1]);
+    /// ```
+    ///
+    /// [`try_resize`]: ArrayVec::try_resize
+    /// [`try_resize_with`]: ArrayVec::try_resize_with
+    /// [`resize_with`]: ArrayVec::resize_with
+    /// [`Clone`]: core::clone::Clone
+    /// [`Default`]: core::default::Default
+    /// [`Default::default`]: core::default::Default::default
+    #[inline]
+    pub fn resize_with<F>(&mut self, new_len: usize, f: F)
+    where
+        F: FnMut() -> T,
+    {
+        self.try_resize_with(new_len, f)
+            .expect("insufficient capacity")
+    }
+
+    /// Tries to resize the array-vector in-place so that `len` is equal to `new_len`.
+    ///
+    /// This is a non-panic version of [`resize_with`].
+    ///
+    /// If `new_len` is greater than `len`, the array-vector is extended by the difference,
+    /// with each additional slot filled with the result of calling the closure `f`.
+    /// The return values from `f` will end up in the array-vector in the order they have been
+    /// generated.
+    ///
+    /// If `new_len` is less than `len`, the array-vector is simply truncated.
+    ///
+    /// This method uses a closure to create new values on every push.
+    /// If you’d rather [`Clone`] a given value, use [`try_resize`].
+    /// If you want to use the [`Default`] trait to generate values, you can pass
+    /// [`Default::default`] as the second argument.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use cds::{array_vec, errors::CapacityError};
+    /// # fn foo() -> Result<(), CapacityError> {
+    /// let mut a = array_vec![5;];
+    /// assert_eq!(a, []);
+    ///
+    /// a.try_resize_with(3, Default::default)?;
+    /// assert_eq!(a, [0, 0, 0]);
+    ///
+    /// let mut g = 2;
+    /// a.try_resize_with(5, move || { g += 1; g })?;
+    /// assert_eq!(a, [0, 0, 0, 3, 4]);
+    ///
+    /// a.try_resize_with(1, || 1)?;
+    /// assert_eq!(a, [0]);
+    ///
+    /// assert!(matches!(a.try_resize_with(10, || 7), Err(CapacityError)));
+    /// # Ok(())
+    /// # }
+    /// # foo();
+    /// ```
+    ///
+    /// [`try_resize`]: ArrayVec::try_resize
+    /// [`resize_with`]: ArrayVec::resize_with
+    /// [`Clone`]: core::clone::Clone
+    /// [`Default`]: core::default::Default
+    /// [`Default::default`]: core::default::Default::default
+    pub fn try_resize_with<F>(&mut self, new_len: usize, mut f: F) -> Result<(), CapacityError>
+    where
+        F: FnMut() -> T,
+    {
+        if new_len > Self::CAPACITY {
+            return Err(CapacityError);
+        }
+
+        if new_len < self.len() {
+            self.truncate(new_len);
+            return Ok(());
+        }
+
+        while self.len() < new_len {
+            unsafe { self.push_unchecked(f()) };
+        }
+
+        Ok(())
+    }
 }
 
 impl<T, L, SM, const C: usize> ArrayVec<T, L, SM, C>
@@ -1215,6 +1398,95 @@ where
     L: LengthType,
     SM: SpareMemoryPolicy<T>,
 {
+    /// Resizes the array-vector in-place so that `len` is equal to `new_len`.
+    ///
+    /// If `new_len` is greater than `len`, the array-vector is extended by the difference,
+    /// with each additional slot filled with `value`. If `new_len` is less than `len`,
+    /// the array-vector is simply truncated.
+    ///
+    /// If you need only to resize to a smaller size, use [`truncate`].
+    ///
+    /// # Panics
+    ///
+    /// This method panics if `new_len > CAPACITY`. To avoid panic use [`try_resize`] which
+    /// returns [`CapacityError`] instead.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use cds::array_vec;
+    /// let mut a = array_vec![5;];
+    /// assert_eq!(a, []);
+    ///
+    /// a.resize(2, 1);
+    /// assert_eq!(a, [1, 1]);
+    ///
+    /// a.resize(4, 5);
+    /// assert_eq!(a, [1, 1, 5, 5]);
+    ///
+    /// a.resize(1, 7);
+    /// assert_eq!(a, [1]);
+    /// ```
+    ///
+    /// [`truncate`]: ArrayVec::truncate
+    /// [`try_resize`]: ArrayVec::try_resize
+    #[inline]
+    pub fn resize(&mut self, new_len: usize, value: T) {
+        self.try_resize(new_len, value)
+            .expect("insufficient capacity");
+    }
+
+    /// Tries to resize the array-vector in-place so that `len` is equal to `new_len`.
+    ///
+    /// This method returns [`CapacityError`] if `new_len > CAPACITY`.
+    ///
+    /// This is a non-panic version of [`resize`].
+    ///
+    /// If `new_len` is greater than `len`, the array-vector is extended by the difference,
+    /// with each additional slot filled with `value`. If `new_len` is less than `len`,
+    /// the array-vector is simply truncated.
+    ///
+    /// If you need only to resize to a smaller size, use [`truncate`].
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use cds::{array_vec, errors::CapacityError};
+    /// # fn foo() -> Result<(), CapacityError> {
+    /// let mut a = array_vec![5; 1];
+    /// assert_eq!(a, [1]);
+    ///
+    /// a.try_resize(5, 7)?;
+    /// assert_eq!(a, [1, 7, 7, 7, 7]);
+    ///
+    /// a.try_resize(2, 0)?;
+    /// assert_eq!(a, [1, 7]);
+    ///
+    /// assert!(matches!(a.try_resize(10, 7), Err(CapacityError)));
+    /// # Ok(())
+    /// # }
+    /// # foo();
+    /// ```
+    ///
+    /// [`truncate`]: ArrayVec::truncate
+    /// [`resize`]: ArrayVec::resize
+    pub fn try_resize(&mut self, new_len: usize, value: T) -> Result<(), CapacityError> {
+        if new_len > Self::CAPACITY {
+            return Err(CapacityError);
+        }
+
+        if new_len < self.len() {
+            self.truncate(new_len);
+            return Ok(());
+        }
+
+        while self.len() < new_len {
+            unsafe { self.push_unchecked(value.clone()) };
+        }
+
+        Ok(())
+    }
+
     #[inline]
     fn _clone_from(&mut self, other: &Self) {
         unsafe {
